"""
# CardActions

"""

import solara
import solara.lab
from solara.website.components import NoPage
from solara.website.utils import apidoc

title = "CardActions"

Page = NoPage


__doc__ += apidoc(solara.CardActions.f)  # type: ignore



"""# use_trait_observe"""

import solara
import solara.autorouting
import solara.lab
from solara.website.utils import apidoc

from . import NoPage

title = "use_trait_observe"
Page = NoPage
__doc__ += apidoc(solara.use_trait_observe)  # type: ignore
